@@ -10,7 +10,7 @@ from enum import Enum
 from .errors import EqlError, EqlCompileError
 from .signatures import SignatureMixin
 from .types import TypeHint, NodeInfo  # noqa: F401
-from .utils import to_unicode, is_string, is_number, ParserConfig, fold_case
+from .utils import to_unicode, is_string, is_number, ParserConfig, fold_case, chr_compat
 
 __all__ = (
     # base classes
@@ -335,8 +335,13 @@ class String(Literal):
     def unescape(cls, s):
         """Unescape an EQL rendered string."""
         def replace_callback(sub):
-            return cls.reverse_patterns.get(sub.group(), sub.group())
-        return re.sub(r"\\.", replace_callback, s)
+            original = sub.group()
+            if original.startswith("\\u{"):
+                hex_digits = original[3:-1]
+                as_hex = int(hex_digits, 16)
+                return chr_compat(as_hex)
+            return cls.reverse_patterns[sub.group()]
+        return re.sub(r"\\u\{.+\}|\\[^u]", replace_callback, s)
 
     def _render(self):
         return '"{}"'.format(self.escape(self.value))
@@ -405,14 +410,16 @@ class Field(Expression):
 
     field_re = re.compile("^[_A-Za-z][_A-Za-z0-9]*$")
 
-    def __init__(self, base, path=None):
+    def __init__(self, base, path=None, as_var=False):
         """Query the event for the field expression.
 
         :param str base: The root field
         :param list[str|int] path: The sub fields and array positions
+        :param bool as_var: Render the node as a variable
         """
         self.base = base
         self.path = path or []
+        self.as_var = as_var
 
     def query_multiple_events(self):  # type: () -> (int, Field)
         """Get the index into the event array and query."""
@@ -436,7 +443,10 @@ class Field(Expression):
         return key
 
     def _render(self):
-        text = [self.escape_ident(self.base)]
+        text = []
+        if self.as_var:
+            text.append("$")
+        text.append(self.escape_ident(self.base))
 
         for key in self.path:
             if is_number(key):
