@@ -2,7 +2,10 @@
 import re
 from collections import defaultdict, deque
 from contextlib import contextmanager
+
+from .ast import TimeUnit
 from .schema import Schema
+from .types import NodeInfo, TypeHint
 from .utils import is_string, to_unicode
 
 
@@ -110,7 +113,7 @@ class Walker(object):
         self.in_pipes = False
 
         incoming_schema = [Schema({event_type: {}}) for event_type in self.output_event_types]
-        output_schemas = node.output_schemas(node.arguments, None, incoming_schema)
+        output_schemas = node.output_schemas([NodeInfo(a, TypeHint.Unknown) for a in node.arguments], incoming_schema)
         self.output_event_types = [next(iter(s.schema.keys())) for s in output_schemas]
 
     def _walk_default(self, node, *args, **kwargs):
@@ -242,6 +245,18 @@ class ConfigurableWalker(RecursiveWalker):
             self._schema = Schema(**self.get_config('schema'))
         super(ConfigurableWalker, self).__init__()
 
+    def convert_time_range(self, node):  # type: (eql.ast.TimeRange) -> (int|float)
+        """Convert a time range to a timestamp delta."""
+        tick_rate = TimeUnit.Seconds.as_milliseconds()
+        node_ms = node.as_milliseconds() // tick_rate
+
+        if not isinstance(self.time_unit, float) and self.time_unit > tick_rate and self.time_unit % tick_rate == 0:
+            # strictly use integer math if we can safely divide the engine's rate by TimeUnits
+            return self.time_unit * node_ms
+        else:
+            # if it doesn't evenly divide, resort to floating point math
+            return float(self.time_unit) * node_ms
+
     @property
     def schema(self):
         """Get the current engine schema."""
